DownloadProgress class

Progress of the file that is being downloaded from the originalUrl.

Constructors

DownloadProgress(String originalUrl, int? totalSize, int downloaded)
const

Properties

downloaded → int
Total of currently downloaded bytes.
final
hashCode → int
The hash code for this object.
no setterinherited
originalUrl → String
Url from which the file is coming.
finalinherited
progress → double?
download progress as an double between 0 and 1. When the final size is unknown or the downloaded size exceeds the total size progress is null.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
totalSize → int?
Final size of the download. If total size is unknown this will be null.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited