EncodedImage class

A description of an encoded image.

Used in PaletteGenerator.fromByteData.

Constructors

EncodedImage(ByteData byteData, {required int width, required int height})
Creates a description of an encoded image.
const

Properties

byteData → ByteData
Encoded image byte data.
final
hashCode → int
The hash code for this object.
no setterinherited
height → int
Image height.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
width → int
Image width.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited