FormData class

Constructors

FormData(Map<String, dynamic> map)

Properties

boundary → String
final
fields → List<MapEntry<String, String>>
The form fields to send for this request.
final
files → List<MapEntry<String, MultipartFile>>
The files to send for this request
final
hashCode → int
The hash code for this object.
no setterinherited
length → int
The length of the request body from this FormData
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toBytes() → Future<List<int>>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited