GetDelegate class

Inheritance
Implemented types
Mixed-in types
  • ListenableMixin
  • ListNotifierMixin

Constructors

GetDelegate({GetPage? notFoundRoute, List<NavigatorObserver>? navigatorObservers, TransitionDelegate? transitionDelegate, PopMode backButtonPopMode = PopMode.History, PreventDuplicateHandlingMode preventDuplicateHandlingMode = PreventDuplicateHandlingMode.ReorderRoutes})

Properties

backButtonPopMode → PopMode
final
currentConfiguration → GetNavConfig?
Called by the Router when it detects a route information may have changed as a result of rebuild.
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
hasListeners → bool
no setterinherited
history → List<GetNavConfig>
final
listeners → int
no setterinherited
no setter
final
notFoundRoute → GetPage
final
parameters → Map<String, String>
no setter
preventDuplicateHandlingMode → PreventDuplicateHandlingMode
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
transitionDelegate → TransitionDelegate?
final

Methods

addListener(GetStateUpdate listener) → Disposer
Register a closure to be called when the object notifies its listeners.
inherited
addListenerId(Object? key, GetStateUpdate listener) → Disposer
inherited
arguments<T>() → T
backUntil(String fullRoute, {PopMode popMode = PopMode.Page}) → Future<void>
Removes routes according to PopMode until it reaches the specifc fullRoute, DOES NOT remove the fullRoute
build(BuildContext context) → Widget
Called by the Router to obtain the widget tree that represents the current state.
override
canPopHistory() → Future<bool>
canPopPage() → Future<bool>
dispose() → void
inherited
disposeId(Object id) → void
To dispose an id from future updates(), this ids are registered by GetBuilder() or similar, so is a way to unlink the state change with the Widget from the Controller.
inherited
getVisualPages() → List<GetPage>
gets the visual pages from the current history entry
handlePopupRoutes({Object? result}) → Future<bool>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyChildrens() → void
inherited
offAndToNamed<T>(String page, {dynamic arguments, int? id, dynamic result, Map<String, String>? parameters, PopMode popMode = PopMode.History}) → Future<T?>?
offNamed<T>(String page, {dynamic arguments, Map<String, String>? parameters}) → Future<T>
popHistory() → Future<GetNavConfig?>
popRoute({Object? result, PopMode popMode = PopMode.Page}) → Future<bool>
Called by the Router when the Router.backButtonDispatcher reports that the operating system is requesting that the current route be popped.
override
pushHistory(GetNavConfig config, {bool rebuildStack = true}) → Future<void>
Adds a new history entry and waits for the result
refresh() → void
inherited
refreshGroup(Object id) → void
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that the object notifies.
inherited
removeListenerId(Object id, VoidCallback listener) → void
inherited
runMiddleware(GetNavConfig config) → Future<GetNavConfig?>
setInitialRoutePath(GetNavConfig configuration) → Future<void>
Called by the Router at startup with the structure that the RouteInformationParser obtained from parsing the initial route.
inherited
setNewRoutePath(GetNavConfig configuration) → Future<void>
Called by the Router when the Router.routeInformationProvider reports that a new route has been pushed to the application by the operating system.
override
setRestoredRoutePath(GetNavConfig configuration) → Future<void>
Called by the Router during state restoration.
inherited
toNamed<T>(String page, {dynamic arguments, Map<String, String>? parameters}) → Future<T>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited