GetNavConfig class

This config enables us to navigate directly to a sub-url

Inheritance

Constructors

GetNavConfig({required List<GetPage> currentTreeBranch, required String? location, required Object? state})

Properties

currentPage → GetPage?
no setter
currentTreeBranch → List<GetPage>
final
hashCode → int
The hash code for this object.
no setterinherited
location → String
The location of the application.
no setterinherited
locationString → String
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state → Object?
The state of the application in the uri.
finalinherited
uri → Uri
The uri location of the application.
no setterinherited

Methods

copyWith({List<GetPage>? currentTreeBranch, required String? location, required Object? state}) → GetNavConfig
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromRoute(String route) → GetNavConfig?