MiddlewareRunner class

Constructors

MiddlewareRunner(List<GetMiddleware>? _middlewares)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
runOnBindingsStart(List<Bindings>? bindings) → List<Bindings>?
runOnPageBuildStart(GetPageBuilder? page) → GetPageBuilder?
runOnPageBuilt(Widget page) → Widget
runOnPageCalled(GetPage? page) → GetPage?
runOnPageDispose() → void
runRedirect(String? route) → RouteSettings?
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited