WaterDropMaterialHeader class

attach the waterdrop effect to MaterialClassicHeader

Inheritance
Available extensions

Constructors

WaterDropMaterialHeader({Key? key, String? semanticsLabel, double distance = 60.0, double offset = 0, String? semanticsValue, Color color = Colors.white, Color? backgroundColor})
const

Properties

backgroundColor → Color?
see flutter RefreshIndicator documents,the meaning same with that
finalinherited
color → Color?
see flutter RefreshIndicator documents,the meaning same with that
finalinherited
completeDuration → Duration
the stopped time when refresh complete or fail
finalinherited
distance → double
Distance from the top when refreshing
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
height → double
the visual extent indicator
finalinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
marginZero → Widget

Available on Widget, provided by the WidgetMarginX extension

no setter
offset → double
finalinherited
paddingZero → Widget

Available on Widget, provided by the WidgetPaddingX extension

no setter
refreshStyle → RefreshStyle?
refresh display style
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
semanticsLabel → String?
see flutter RefreshIndicator documents,the meaning same with that
finalinherited
semanticsValue → String?
see flutter RefreshIndicator documents,the meaning same with that
finalinherited
sliverBox → Widget

Available on Widget, provided by the WidgetSliverBoxX extension

no setter

Methods

center() → Widget

Available on Widget, provided by the FpjExtensionWidget extension

clipRadius(double radius) → Widget

Available on Widget, provided by the FpjExtensionWidget extension

colorBg(Color color) → Widget

Available on Widget, provided by the FpjExtensionWidget extension

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<StatefulWidget>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
marginAll(double margin) → Widget

Available on Widget, provided by the WidgetMarginX extension

marginOnly({double left = 0.0, double top = 0.0, double right = 0.0, double bottom = 0.0}) → Widget

Available on Widget, provided by the WidgetMarginX extension

marginSymmetric({double horizontal = 0.0, double vertical = 0.0}) → Widget

Available on Widget, provided by the WidgetMarginX extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
obx() → Widget

Available on Widget, provided by the FpjExtensionWidget extension

onTap(GestureTapCallback? onTap) → Widget

Available on Widget, provided by the FpjExtensionWidget extension

onTapWithInk(GestureTapCallback onTap, {Color? hoverColor, Color? splashColor, double? radius, double? radiusTopLeft, double? radiusTopRight, double? radiusBottomLeft, double? radiusBottomRight}) → Widget

Available on Widget, provided by the FpjExtensionWidget extension

paddingAll(double padding) → Widget

Available on Widget, provided by the WidgetPaddingX extension

paddingOnly({double left = 0.0, double top = 0.0, double right = 0.0, double bottom = 0.0}) → Widget

Available on Widget, provided by the WidgetPaddingX extension

paddingSymmetric({double horizontal = 0.0, double vertical = 0.0}) → Widget

Available on Widget, provided by the WidgetPaddingX extension

positioned({double? left, dynamic right, dynamic top, dynamic bottom}) → Positioned

Available on Widget, provided by the FpjExtensionWidget extension

toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited
widgetBadgeNum(int num, {BadgeStyle? style}) → Widget

Available on Widget, provided by the FpjExtensionWidget extension

Operators

operator ==(Object other) → bool
The equality operator.
inherited