FpjWidgetApp class

Inheritance
Available extensions

Constructors

FpjWidgetApp({Widget? home, VoidCallback? onInit, VoidCallback? onReady, VoidCallback? onDispose, Iterable<Locale>? supportedLocales, Size? size, String? initialRoute, List<GetPage>? getPages, String title = "", Color? scaffoldBackgroundColor, AppBarTheme? appBarTheme, List<NavigatorObserver>? navigatorObservers, ValueChanged<Routing?>? routingCallback, Map<String, Widget Function(BuildContext)> routes = const <String, WidgetBuilder>{}, Key? key})
const

Properties

appBarTheme → AppBarTheme?
final
getPages → List<GetPage>?
final
hashCode → int
The hash code for this object.
no setterinherited
home → Widget?
final
initialRoute → String?
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
marginZero → Widget

Available on Widget, provided by the WidgetMarginX extension

no setter
final
onDispose → VoidCallback?
final
onInit → VoidCallback?
final
onReady → VoidCallback?
final
paddingZero → Widget

Available on Widget, provided by the WidgetPaddingX extension

no setter
routes → Map<String, Widget Function(BuildContext)>
final
routingCallback → ValueChanged<Routing?>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scaffoldBackgroundColor → Color?
final
size → Size?
final
sliverBox → Widget

Available on Widget, provided by the WidgetSliverBoxX extension

no setter
supportedLocales → Iterable<Locale>?
final
title → String
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
center() → Widget

Available on Widget, provided by the FpjExtensionWidget extension

clipRadius(double radius) → Widget

Available on Widget, provided by the FpjExtensionWidget extension

colorBg(Color color) → Widget

Available on Widget, provided by the FpjExtensionWidget extension

createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
marginAll(double margin) → Widget

Available on Widget, provided by the WidgetMarginX extension

marginOnly({double left = 0.0, double top = 0.0, double right = 0.0, double bottom = 0.0}) → Widget

Available on Widget, provided by the WidgetMarginX extension

marginSymmetric({double horizontal = 0.0, double vertical = 0.0}) → Widget

Available on Widget, provided by the WidgetMarginX extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
obx() → Widget

Available on Widget, provided by the FpjExtensionWidget extension

onTap(GestureTapCallback? onTap) → Widget

Available on Widget, provided by the FpjExtensionWidget extension

onTapWithInk(GestureTapCallback onTap, {Color? hoverColor, Color? splashColor, double? radius, double? radiusTopLeft, double? radiusTopRight, double? radiusBottomLeft, double? radiusBottomRight}) → Widget

Available on Widget, provided by the FpjExtensionWidget extension

paddingAll(double padding) → Widget

Available on Widget, provided by the WidgetPaddingX extension

paddingOnly({double left = 0.0, double top = 0.0, double right = 0.0, double bottom = 0.0}) → Widget

Available on Widget, provided by the WidgetPaddingX extension

paddingSymmetric({double horizontal = 0.0, double vertical = 0.0}) → Widget

Available on Widget, provided by the WidgetPaddingX extension

positioned({double? left, dynamic right, dynamic top, dynamic bottom}) → Positioned

Available on Widget, provided by the FpjExtensionWidget extension

toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited
widgetBadgeNum(int num, {BadgeStyle? style}) → Widget

Available on Widget, provided by the FpjExtensionWidget extension

Operators

operator ==(Object other) → bool
The equality operator.
inherited